#ifndef SHARED_SURVEY_READ_PARAM_H
#define SHARED_SURVEY_READ_PARAM_H

SURVEY_DATA *
read_choice_parameters(int id);

SURVEY_DATA *
read_custom_parameters(int id);


SURVEY_DATA *
read_likert_parameters(int id);


SURVEY_DATA *
read_text_parameters(int id);

SURVEY_DATA *
read_memo_parameters(int  id);


void
read_com_parameters(int *is_admin, char *key, char *count, int *pre_id);



SURVEY_DATA * read_title_parameters(int id);

#endif
